@@ -5,17 +5,20 @@ from __future__ import annotations
 
 import inspect
 from contextlib import ExitStack, contextmanager
-from typing import Iterator, cast
+from typing import TYPE_CHECKING, cast
 
 import click
 from markdown.extensions.toc import slugify
 
 from ._exceptions import MkDocsClickException
 
+if TYPE_CHECKING:
+    from collections.abc import Iterator
+
 
 def make_command_docs(
     prog_name: str,
-    command: click.BaseCommand,
+    command: click.Command,
     depth: int = 0,
     style: str = "plain",
     remove_ascii_art: bool = False,
@@ -42,7 +45,7 @@ def make_command_docs(
 
 def _recursively_make_command_docs(
     prog_name: str,
-    command: click.BaseCommand,
+    command: click.Command,
     parent: click.Context | None = None,
     depth: int = 0,
     style: str = "plain",
@@ -90,20 +93,30 @@ def _recursively_make_command_docs(
 
 
 def _build_command_context(
-    prog_name: str, command: click.BaseCommand, parent: click.Context | None
+    prog_name: str, command: click.Command, parent: click.Context | None
 ) -> click.Context:
-    return click.Context(cast(click.Command, command), info_name=prog_name, parent=parent)
+    # https://github.com/pallets/click/blob/8.1.8/src/click/core.py#L859-L862
+    return command.context_class(
+        cast(click.Command, command),
+        info_name=prog_name,
+        parent=parent,
+        **command.context_settings,
+    )
 
 
-def _get_sub_commands(command: click.Command, ctx: click.Context) -> list[click.Command]:
+def _get_sub_commands(
+    command: click.Command | click.Group, ctx: click.Context
+) -> list[click.Command]:
     """Return subcommands of a Click command."""
     subcommands = getattr(command, "commands", {})
     if subcommands:
         return list(subcommands.values())
 
-    if not isinstance(command, click.MultiCommand):
+    if not _is_command_group(command):
         return []
 
+    command = cast(click.Group, command)
+
     subcommands = []
 
     for name in command.list_commands(ctx):
@@ -187,7 +200,7 @@ def _make_usage(ctx: click.Context) -> Iterator[str]:
     formatter = ctx.make_formatter()
     pieces = ctx.command.collect_usage_pieces(ctx)
     formatter.write_usage(ctx.command_path, " ".join(pieces), prefix="")
-    usage = formatter.getvalue().rstrip("\n")
+    usage = formatter.getvalue().strip()
 
     yield "**Usage:**"
     yield ""
@@ -242,9 +255,10 @@ def _make_plain_options(ctx: click.Context, show_hidden: bool = False) -> Iterat
         # First line is redundant "Options"
         option_lines = option_lines[1:]
 
-        if not option_lines:  # pragma: no cover
-            # We expect at least `--help` to be present.
-            raise RuntimeError("Expected at least one option")
+        # It's possible to define a command with no options, especially common when
+        # forwarding arguments to an external process.
+        if not option_lines:
+            return
 
         yield "**Options:**"
         yield ""
@@ -325,6 +339,12 @@ def _make_table_options(ctx: click.Context, show_hidden: bool = False) -> Iterat
 
     options = [param for param in ctx.command.get_params(ctx) if isinstance(param, click.Option)]
     options = [option for option in options if not option.hidden or show_hidden]
+
+    # It's possible to define a command with no options, especially common when
+    # forwarding arguments to an external process.
+    if not options:
+        return
+
     option_rows = [_format_table_option_row(option) for option in options]
 
     yield "**Options:**"
@@ -360,3 +380,8 @@ def _make_subcommands_links(
             help_string = "*No description was provided with this command.*"
         yield f"- *{command_bullet}*: {help_string}"
     yield ""
+
+
+def _is_command_group(command: click.Command) -> bool:
+    # https://github.com/pallets/click/blob/8.1.8/src/click/core.py#L1806-L1811
+    return isinstance(command, click.Group) or hasattr(command, "command_class")
