@@ -50,14 +50,14 @@ cli_named.add_command(bar)
 cli_named.add_command(hidden)
 
 
-class MultiCLI(click.MultiCommand):
+class GroupCLI(click.Group):
     def list_commands(self, ctx):
         return ["foo", "bar"]
 
     def get_command(self, ctx, name):
         cmds = {"foo": foo, "bar": bar}
-        return cmds.get(name, None)
+        return cmds.get(name)
 
 
-multi_named = MultiCLI(name="multi", help="Main entrypoint for this dummy program")
-multi = MultiCLI(help="Main entrypoint for this dummy program")
+group_named = GroupCLI(name="group", help="Main entrypoint for this dummy program")
+group = GroupCLI(help="Main entrypoint for this dummy program")
