@@ -42,6 +42,13 @@ def hello_ascii_art():
     """
 
 
+@click.command(context_settings={"help_option_names": []})
+def hello_no_options():
+    """
+    Hello, world!
+    """
+
+
 HELLO_EXPECTED = dedent(
     """
     # hello
@@ -64,6 +71,21 @@ HELLO_EXPECTED = dedent(
 ).lstrip()
 
 
+HELLO_EXPECTED_NO_OPTIONS = dedent(
+    """
+    # hello
+
+    Hello, world!
+
+    **Usage:**
+
+    ```text
+    hello [OPTIONS]
+    ```
+    """
+).lstrip()
+
+
 def test_basic():
     output = "\n".join(make_command_docs("hello", hello))
     assert output == HELLO_EXPECTED
@@ -97,6 +119,11 @@ def test_basic_ascii_art():
     assert output == HELLO_EXPECTED
 
 
+def test_basic_no_options():
+    output = "\n".join(make_command_docs("hello", hello_no_options))
+    assert output == HELLO_EXPECTED_NO_OPTIONS
+
+
 @click.command()
 @click.option("-d", "--debug", help="Include debug output")
 @click.option("--choice", type=click.Choice(["foo", "bar"]), default="foo")
@@ -175,7 +202,7 @@ def test_style_table(command, expected):
     assert output == expected
 
 
-class MultiCLI(click.MultiCommand):
+class GroupCLI(click.Group):
     def list_commands(self, ctx):
         return ["single-command"]
 
@@ -184,26 +211,26 @@ class MultiCLI(click.MultiCommand):
 
 
 @pytest.mark.parametrize(
-    "multi",
+    "group",
     [
-        pytest.param(MultiCLI("multi", help="Multi help"), id="explicit-name"),
-        pytest.param(MultiCLI(help="Multi help"), id="no-name"),
+        pytest.param(GroupCLI("group", help="Group help"), id="explicit-name"),
+        pytest.param(GroupCLI(help="Group help"), id="no-name"),
     ],
 )
-def test_custom_multicommand(multi):
+def test_custom_group(group):
     """
-    Custom `MultiCommand` objects are supported (i.e. not just `Group` multi-commands).
+    Custom `Group` objects are supported.
     """
     expected = dedent(
         """
-        # multi
+        # group
 
-        Multi help
+        Group help
 
         **Usage:**
 
         ```text
-        multi [OPTIONS] COMMAND [ARGS]...
+        group [OPTIONS] COMMAND [ARGS]...
         ```
 
         **Options:**
@@ -219,7 +246,7 @@ def test_custom_multicommand(multi):
         **Usage:**
 
         ```text
-        multi hello [OPTIONS]
+        group hello [OPTIONS]
         ```
 
         **Options:**
@@ -231,31 +258,31 @@ def test_custom_multicommand(multi):
         """
     ).lstrip()
 
-    output = "\n".join(make_command_docs("multi", multi))
+    output = "\n".join(make_command_docs("group", group))
     assert output == expected
 
 
 @pytest.mark.parametrize(
-    "multi",
+    "group",
     [
-        pytest.param(MultiCLI("multi", help="Multi help"), id="explicit-name"),
-        pytest.param(MultiCLI(help="Multi help"), id="no-name"),
+        pytest.param(GroupCLI("group", help="Group help"), id="explicit-name"),
+        pytest.param(GroupCLI(help="Group help"), id="no-name"),
     ],
 )
-def test_custom_multicommand_with_list_subcommands(multi):
+def test_custom_group_with_list_subcommands(group):
     """
-    Custom `MultiCommand` objects are supported (i.e. not just `Group` multi-commands).
+    Custom `Group` objects are supported.
     """
     expected = dedent(
         """
-        # multi
+        # group
 
-        Multi help
+        Group help
 
         **Usage:**
 
         ```text
-        multi [OPTIONS] COMMAND [ARGS]...
+        group [OPTIONS] COMMAND [ARGS]...
         ```
 
         **Options:**
@@ -275,7 +302,7 @@ def test_custom_multicommand_with_list_subcommands(multi):
         **Usage:**
 
         ```text
-        multi hello [OPTIONS]
+        group hello [OPTIONS]
         ```
 
         **Options:**
@@ -287,7 +314,7 @@ def test_custom_multicommand_with_list_subcommands(multi):
         """
     ).lstrip()
 
-    output = "\n".join(make_command_docs("multi", multi, list_subcommands=True))
+    output = "\n".join(make_command_docs("group", group, list_subcommands=True))
     assert output == expected
 
 
